/*
 * Copyright (c) 2022 Verizon.  Licensed under Verizon EDS SDK Software Licensing Agreement.  See "EDS SDK License Agreement.pdf"
 */

package com.verizon.mec.edsclientsdk.sample;

import android.content.Context;
import android.net.Network;
import android.util.Log;

import com.verizon.mec.edsclientsdk.EdsClientSdkFactory;
import com.verizon.mec.edsclientsdk.api.IAsyncOpHandle;
import com.verizon.mec.edsclientsdk.api.IEdgeDiscoveryCallback;
import com.verizon.mec.edsclientsdk.api.IEdsClientSdk;
import com.verizon.mec.edsclientsdk.data.EdsServiceEndpoint;
import com.verizon.mec.edsclientsdkutils.EdsClientSdkLogWrapper;

/**
 * Basic interaction showing Edge Discovery using IDMS Device attestation, UE location based on IP,
 * and SDK defaults for environment (production), timeout (30-sec), network ,etc.
 */
public class EdsSdkBasicSample {


    /**
     * NOTE: Edge discovery requires VZW cellular network connection.  It is possible (and
     * may be desirable) to use edge service endpoint when a WIFI connection is available, but requests
     * to the edge service endpoint (the result of the edge discovery operation) may need to be explicitly
     * routed over the cellular connection
     *
     * When using a non-default network, the application must pass in the Cellular Network connection
     *
     * @param context context.
     * @param targetCellularNetwork Network connection used to obtain device identity (IP).  Later, likely same network is used when interacting with result edge service endpoint.
     */
    public void sampleSdkCreation(Context context, Network targetCellularNetwork) {

        IEdsClientSdk edsSdk = new EdsClientSdkFactory().getSdkBuilder(context)
                .setIdmsAttestAuthenticator("someGoogleApiKey", "someMecAppId")
                .build();

        // Perform edge discovery - uses UE location w/ default settings (IPv4, default cellular network)
        IAsyncOpHandle opHandle = edsSdk.discoverEdgeServices(context, mSdkCallback,
                "someEdsEndpointsId", targetCellularNetwork, null);
    }

    IEdgeDiscoveryCallback mSdkCallback = new IEdgeDiscoveryCallback() {
        @Override
        public void onSuccess(EdsServiceEndpoint[] endpoints, String edsJsonResult) {

            Log.i("EdsSample", "onSuccess: " + edsJsonResult);
            // NOTE:  Edge service URLs/IPs will likely NOT be available over WIFI network connection.
        }

        @Override
        public void onError(int errorCode, String errorMessage, Throwable ex) {
            Log.w("EdsSample", "onError: " + errorCode + " : " + errorMessage, ex);
            // NOTE: See full example for details on error results
        }
    };
}
